@@ -1,6 +1,6 @@
 # -*- cperl; cperl-indent-level: 4 -*-
 # Copyright (C) 2020-2021, Roland van Ipenburg
-package Geo::METAR::Deduced v0.0.6;
+package Geo::METAR::Deduced v1.0.1;
 use Moose;
 use MooseX::NonMoose;
 use Geo::METAR;
@@ -109,7 +109,7 @@ my %rules = ();
 
 sub _len {
     my ( $amount, $unit ) = @_;
-    return Class::Measure::Scientific::FX_992vb->length( $amount, $unit );
+    return Class::Measure::Scientific::FX_992vb->length( $amount + 0, $unit );
 }
 
 my %vis_min = ();
@@ -136,10 +136,12 @@ if ( !$combined->is_universal ) {
 
 has 'rules' => ( 'isa' => 'Str', 'is' => 'rw', 'default' => $DEFAULT_RULES );
 
-before 'metar' => sub {
+around 'metar' => sub {
+    my $orig = shift;
     my $self = shift;
     my $args = shift;
-    if ($args) {
+    if ( defined $args ) {
+        $args =~ tr{\n}{ };
 
         # Reset the object when a new METAR string is loaded because the parent
         # doesn't do that for us:
@@ -152,6 +154,7 @@ before 'metar' => sub {
         }
         ###l4p $log->debug( join q{,}, @{ $self->{'sky'} } );
     }
+    return $self->$orig($args);
 };
 
 after 'metar' => sub {
@@ -170,7 +173,7 @@ after 'metar' => sub {
 
 sub date {
     my $self = shift;
-    return $self->{'DATE'};
+    return $self->{'DATE'} + 0;
 }
 
 ## no critic (ProhibitBuiltinHomonyms)
@@ -187,8 +190,8 @@ sub mode {
 
 sub wind_dir {
     my $self = shift;
-    return Class::Measure::Scientific::FX_992vb->angle( $self->{'WIND_DIR_DEG'},
-        $DEG );
+    return Class::Measure::Scientific::FX_992vb->angle(
+        $self->{'WIND_DIR_DEG'} + 0, $DEG );
 }
 
 sub wind_dir_eng {
@@ -210,7 +213,7 @@ sub wind_low {
     my $self = shift;
     return
       defined $self->{'WIND_VAR_1'}
-      ? Class::Measure::Scientific::FX_992vb->angle( $self->{'WIND_VAR_1'},
+      ? Class::Measure::Scientific::FX_992vb->angle( $self->{'WIND_VAR_1'} + 0,
         $DEG )
       : undef;
 }
@@ -219,23 +222,22 @@ sub wind_high {
     my $self = shift;
     return
       defined $self->{'WIND_VAR_2'}
-      ? Class::Measure::Scientific::FX_992vb->angle( $self->{'WIND_VAR_2'},
+      ? Class::Measure::Scientific::FX_992vb->angle( $self->{'WIND_VAR_2'} + 0,
         $DEG )
       : undef;
 }
 
 sub wind_speed {
     my $self = shift;
-    my $wind = $self->{'WIND_KTS'};
-    $wind =~ s{^0*}{}msx;
-    return Class::Measure::Scientific::FX_992vb->speed( $wind, $KNOTS );
+    return Class::Measure::Scientific::FX_992vb->speed( $self->{'WIND_KTS'} + 0,
+        $KNOTS );
 }
 
 sub wind_gust {
     my $self = shift;
     my $gust = $self->{'WIND_GUST_KTS'};
     if ($gust) {
-        $gust =~ s{^0*}{}msx;
+        $gust += 0;
     }
     else {
         $gust = 0;
@@ -247,14 +249,14 @@ sub wind_gust {
 sub temp {
 ## use critic
     my $self = shift;
-    return Class::Measure::Scientific::FX_992vb->temperature( $self->{'TEMP_C'},
-        $CELSIUS );
+    return Class::Measure::Scientific::FX_992vb->temperature(
+        $self->{'TEMP_C'} + 0, $CELSIUS );
 }
 
 sub dew {
     my $self = shift;
-    return Class::Measure::Scientific::FX_992vb->temperature( $self->{'DEW_C'},
-        $CELSIUS );
+    return Class::Measure::Scientific::FX_992vb->temperature(
+        $self->{'DEW_C'} + 0, $CELSIUS );
 }
 
 sub alt {
@@ -272,7 +274,7 @@ sub pressure {
 # This isn't handled in Geo::METAR, it's just tokenized for the parser
 sub _vertical_visibility {
     my $self = shift;
-    my $vv   = $INF;
+    my $vv   = +$INF;
     $self->{'METAR'} =~ m{.*\bVV(?<vv>\d{3})\b.*}msx;
     if ( defined $LAST_PAREN_MATCH{'vv'} ) {
         $vv = $LAST_PAREN_MATCH{'vv'} * $HECTO;
@@ -285,18 +287,16 @@ sub _vertical_visibility {
 sub ceiling {
     my $self = shift;
 
-    my $cloud_ceiling = $INF;
+    my $cloud_ceiling = +$INF;
     my %TEST          = (
         'ICAO' => sub {
             my ($base) = @_;
             return $base < $ICAO_MAX_CEILING;
         },
         'UK' => sub {
-            my ($base) = @_;
             return 1;
         },
         'US' => sub {
-            my ($base) = @_;
             return 1;
         },
     );
@@ -319,7 +319,7 @@ sub ceiling {
             $cloud_ceiling = $vv;
         }
     }
-    return ( $INF eq $cloud_ceiling )
+    return ( $INF == $cloud_ceiling )
       ? _len( $cloud_ceiling,          $FT )
       : _len( $cloud_ceiling * $HECTO, $FT );
 }
@@ -352,33 +352,25 @@ sub visibility {
 sub flight_rule {
     my $self = shift;
     my $lvl;
-## no critic (ProhibitCascadingIfElse)
     if (   $self->visibility()->mile() < $vis_min{'IFR'}->mile()
         || $self->ceiling()->ft() < $ceil_min{'IFR'}->ft() )
     {
         $lvl = $LIFR;
     }
-    elsif ($self->visibility()->mile() >= $vis_min{'IFR'}->mile()
-        && $self->visibility()->mile() < $vis_min{'MVFR'}->mile()
-        || $self->ceiling()->ft() >= $ceil_min{'IFR'}->ft()
-        && $self->ceiling()->ft() < $ceil_min{'MVFR'}->ft() )
+    elsif ($self->visibility()->mile() < $vis_min{'MVFR'}->mile()
+        || $self->ceiling()->ft() < $ceil_min{'MVFR'}->ft() )
     {
         $lvl = $IFR;
     }
-    elsif ($self->visibility()->mile() >= $vis_min{'MVFR'}->mile()
-        && $self->visibility()->mile() <= $vis_min{'VFR'}->mile()
-        || $self->ceiling()->ft() >= $ceil_min{'MVFR'}->ft()
-        && $self->ceiling()->ft() <= $ceil_min{'VFR'}->ft() )
+    elsif ($self->visibility()->mile() <= $vis_min{'VFR'}->mile()
+        || $self->ceiling()->ft() <= $ceil_min{'VFR'}->ft() )
     {
         $lvl = $MVFR;
     }
-    elsif ($self->visibility()->mile() > $vis_min{'VFR'}->mile()
-        && $self->ceiling()->ft() > $ceil_min{'VFR'}->ft() )
-    {
+    else {
         $lvl = $VFR;
     }
 
-    # use critic
     return $lvl;
 }
 
@@ -432,7 +424,7 @@ Geo::METAR::Deduced - deduce aviation information from parsed METAR data
 
 =head1 VERSION
 
-This document describes Geo::METAR::Deduced C<v0.0.6>.
+This document describes Geo::METAR::Deduced C<v1.0.1>.
 
 =head1 SYNOPSIS
 
@@ -662,28 +654,21 @@ None.
 =over 4
 
 =item * Perl 5.16
-
-=item * L<Geo::METAR>
-
-=item * L<Geo::ICOA>
-
-=item * L<Moose>
-
-=item * L<MooseX::NonMoose>
-
-=item * L<Set::Scalar>
-
 =item * L<Class::Measure::Scientific::FX_992vb>
-
-=item * L<Data::Dumper>
-
 =item * L<English>
+=item * L<Geo::ICOA>
+=item * L<Geo::METAR>
+=item * L<Moose>
+=item * L<MooseX::NonMoose>
+=item * L<Readonly> 1.03
+=item * L<Set::Scalar>
 
 =back
 
 =head1 INCOMPATIBILITIES
 
-This module has the same limits as L<Geo::METAR>.
+This module has the same limitations as L<Geo::METAR>. We suspect there is
+also an incompatibility with a threaded version of perl 5.22.1.
 
 =head1 DIAGNOSTICS
 
@@ -695,8 +680,8 @@ There is still plenty to deduce from the format that METAR has to offer in
 it's fullest form.
 
 Please report any bugs or feature requests at
-L<Bitbucket|
-https://bitbucket.org/rolandvanipenburg/geo-metar-deduced/issues>.
+L<Bitbucket
+|https://bitbucket.org/rolandvanipenburg/geo-metar-deduced/issues>.
 
 =head1 AUTHOR
 
